==> transcalc_0.1.orig.tar.gz: transcalc-0.1.orig/src/help.h <==
/*

Copyright (C) 2001  Gopal Narayanan <gopal@astro.umass.edu>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

*/

/* help.h
 */

#ifndef __HELP_H
#define __HELP_H

#include <config.h>

void helpCB(gpointer);
void aboutCB(gpointer);


#define HELPTEXT \
"\n\
Gopal Narayanan <gopal@astro.umass.edu>\n\
\n\
TRANSCALC is an analysis and synthesis tool for calculating the electrical\n\
and physical properties of different kinds of RF and microwave transmission\n\
lines.\n\
\n\
Transcalc was somewhat inspired by the functionality of Agilent Technologies' \n\
commercial program linecalc. Transcalc is built using the GIMP toolkit (GTK) for\n\
its GUI interface. \n\
For each type of transmission line, using dialog boxes, you can enter values\n\
for the various parameters, and either calculate its electrical\n\
properties, or use the given electrical requirements to sythesize physical \n\
parameters of the required transmission line.\n\
\n\
Available transmission lines: \n\
\n\
microstrip\n\
rectangular waveguide\n\
\n\
"

#define ABOUTTEXT \
"\n
Gopal Narayanan <gopal@astro.umass.edu>\n\
\n\
Copyright (C) 2001  Gopal Narayanan <gopal@astro.umass.edu>\n\
\n\
This program is free software; you can redistribute it and/or\n\
modify it under the terms of the GNU General Public License\n\
as published by the Free Software Foundation; either version 2\n\
of the License, or (at your option) any later version.\n\
\n\
This program is distributed in the hope that it will be useful,\n\
but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
GNU General Public License for more details.\n\
\n\
You should have received a copy of the GNU General Public License\n\
along with this program; if not, write to the Free Software\n\
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,\n\
USA.\n\
\n\
\n\
"

#endif

==> transcalc_0.13.orig.tar.gz: transcalc-0.13/src/help.h <==
/*

Copyright (C) 2001  Gopal Narayanan <gopal@astro.umass.edu>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

*/

/* help.h
 *
 * Added myself in the ABOUTTEXT, 8-) ! C.G.
 */

#ifndef __HELP_H
#define __HELP_H

#include <config.h>

void helpCB(gpointer);
void aboutCB(gpointer);


#define HELPTEXT \
"\n\
AUTHORS:\n\
\n\
Gopal Narayanan <gopal@astro.umass.edu>\n\
Claudio Girardi <claudio.girardi@ieee.org>\n\
\n\
TRANSCALC is an analysis and synthesis tool for calculating the electrical\n\
and physical properties of different kinds of RF and microwave transmission\n\
lines.\n\
\n\
Transcalc was somewhat inspired by the functionality of Agilent Technologies' \n\
commercial program linecalc. Transcalc is built using the GIMP toolkit (GTK) for\n\
its GUI interface. \n\
\n\
For each type of transmission line, using dialog boxes, you can enter values\n\
for the various parameters, and either calculate its electrical\n\
properties, or use the given electrical requirements to sythesize physical \n\
parameters of the required transmission line.\n\
\n\
Available transmission lines: \n\
\n\
microstrip\n\
rectangular waveguide\n\
coaxial line\n\
coupled microstrips\n\
\n\
"

#define ABOUTTEXT \
"\n
Gopal Narayanan <gopal@astro.umass.edu>\n\
\n\
Copyright (C) 2001-2002  Gopal Narayanan <gopal@astro.umass.edu>\n\
Copyright (C) 2002 Claudio Girardi <claudio.girardi@ieee.org>
\n\
This program is free software; you can redistribute it and/or\n\
modify it under the terms of the GNU General Public License\n\
as published by the Free Software Foundation; either version 2\n\
of the License, or (at your option) any later version.\n\
\n\
This program is distributed in the hope that it will be useful,\n\
but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
GNU General Public License for more details.\n\
\n\
You should have received a copy of the GNU General Public License\n\
along with this program; if not, write to the Free Software\n\
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,\n\
USA.\n\
\n\
\n\
"

#endif
